@@ -1,17 +1,17 @@
 package Catalyst::View::ByCode;
 {
-  $Catalyst::View::ByCode::VERSION = '0.23';
+  $Catalyst::View::ByCode::VERSION = '0.24';
 }
 
 use Moose;
 extends 'Catalyst::View';
 with 'Catalyst::Component::ApplicationAttribute';
 
-has extension => (is => 'rw', default => '.pl');
-# has root_dir  => (is => 'rw', default => sub { $_[0]->_application->path_to('root/bycode') });
-has root_dir  => (is => 'rw', default => 'root/bycode');
-has wrapper   => (is => 'rw', default => 'wrapper.pl');
-has include   => (is => 'rw', default => sub { [] });
+has extension    => (is => 'rw', default => '.pl');
+has root_dir     => (is => 'rw', default => 'root/bycode');
+has wrapper      => (is => 'rw', default => 'wrapper.pl');
+has include      => (is => 'rw', default => sub { [] });
+has content_type => (is => 'rw', default => 'text/html ; charset=utf-8');
 
 # Config Options:
 #    root_dir => 'bycode',
@@ -44,7 +44,7 @@ Catalyst::View::ByCode - Templating using pure Perl code
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -1048,7 +1048,8 @@ sub process {
     my $self = shift;
     my $c = shift;
     
-    $c->response->body( $self->render($c) );
+    $c->response->content_type($self->content_type);
+    $c->response->body($self->render($c));
     
     return 1; # indicate success
 }
